/*
Redistribution and use in source and binary forms, with or without
modification, is permitted.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
THE POSSIBILITY OF SUCH DAMAGE.
 */
package au.edu.unimelb.htmltokenizer;

import java.util.ArrayList;
import java.util.List;

/**
 * Provides support for splitting HTML data into a series of tokens.
 */
public class TextTokenizer {

	/**
	 * Convert a string into a list of tokens.
	 *
	 * @param string HTML string
	 * @return List of tokens
	 */
	public static List<Token> tokenize(String string) {
		List<Token> tokens = new ArrayList<Token>();

		// States
		//  0 - Reading text
		//  1 - Reading whitespace
		int state=0;

		StringBuffer data = new StringBuffer();
		int length = string.length();
		for(int i=0;i<length;i++) {
			char c = string.charAt(i);
			switch(state) {
			case 0:
				if(c == '.' || c == '*' || c == '"') {
					if(data.length()>0) {
						tokens.add(new Token(data));
						data = new StringBuffer();
					}
					data.append(c);
					tokens.add(new Token(data));
					data = new StringBuffer();
					break;
				}
				if(c == ' ' || c == '\n' || c == '\r') {
					if(data.length()>0) {
						tokens.add(new Token(data));
						data = new StringBuffer();
					}
					state=1;
				}
				data.append(c);
				break;
			case 1:
				if(c == ' ' || c == '\n' || c == '\r') {
					data.append(c);
					break;
				}
				if(c == '.' || c == '*' || c == '"') {
					if(data.length()>0) {
						tokens.add(new Token(data));
						data = new StringBuffer();
					}
					data.append(c);
					tokens.add(new Token(data));
					data = new StringBuffer();
					state = 0;
					break;
				}
				tokens.add(new Token(data));
				data = new StringBuffer();
				state = 0;
				data.append(c);
				break;
			}
		}
		if(data.length()>0) {
			tokens.add(new Token(data));
			data = new StringBuffer();
		}

		return tokens;
	}

	/**
	 * Converts a list of tokens back into the equivalent HTML string.
	 *
	 * @param tokens Tokens to be merged back to HTML.
	 * @return The tokens merged back into a HTML string.
	 */
	public static String untokenize(List<Token> tokens) {
		StringBuffer html = new StringBuffer();

		for(Token token : tokens)
			html.append(token.text);

		return html.toString();
	}

}
