/*
Redistribution and use in source and binary forms, with or without
modification, is permitted.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
THE POSSIBILITY OF SUCH DAMAGE.
 */
package au.edu.unimelb.htmltokenizer;

import java.util.ArrayList;
import java.util.List;

/**
 * Provides support for filtering a list of tokens based on a
 * pre-determined list of valid html tags.
 */
public class TokenFilter {

	public static List<Token> filterTokens(List<Token> tokens, String[] validTags) {
		List<Token> validTokens = new ArrayList<Token>();

		for(Token token : tokens) {
			if(token.type==Token.TEXT) {
				validTokens.add(token);
				continue;
			}
			StringBuffer tag = new StringBuffer();
			for(int i=1;i<token.text.length();i++) {
				char c = token.text.charAt(i);
				if(i==1 && c=='/') continue;
				if(c==' ' || c=='>' || c=='"' || c=='\'' || c=='<' || c=='/' || c=='\\') break;
				tag.append(c);
			}
			boolean allowed = false;
			for(String i : validTags) {
				if(i.equals(tag.toString())) {
					allowed = true;
					break;
				}
			}
			if(allowed)
				validTokens.add(token);
		}

		return validTokens;
	}

	public static String filterTokens(String html, String[] validTags) {
		List<Token> tokens = Tokenizer.tokenize(html);
		tokens = TokenFilter.filterTokens(tokens, validTags);
		return Tokenizer.untokenize(tokens);
	}

}
