/*
Redistribution and use in source and binary forms, with or without
modification, is permitted.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
THE POSSIBILITY OF SUCH DAMAGE.
 */
import au.edu.unimelb.htmltokenizer.Token;
import au.edu.unimelb.htmltokenizer.TokenFilter;
import au.edu.unimelb.htmltokenizer.Tokenizer;
import java.util.List;

/**
 * Test for correct tokenization of various strings.
 */
public class Test {

	public static void assertEquals(int a, int b) {
		if(a != b) throw new RuntimeException(a+"!="+b);
	}

	public static void assertEquals(String a, String b) {
		if(!a.equals(b)) throw new RuntimeException("\""+a+"\"!=\""+b+"\"");
	}
	
	public static void main(String[] arg) {

		List<Token> tokens = null;
		
		System.out.print("Test 1... ");
		tokens = Tokenizer.tokenize("simple test string");
		assertEquals(tokens.size(),1);
		assertEquals(tokens.get(0).text,"simple test string");
		System.out.println(" OK");
		
		System.out.print("Test 2... ");
		tokens = Tokenizer.tokenize("<b>simple</b> test string");
		assertEquals(tokens.size(),4);
		assertEquals(tokens.get(0).text,"<b>");
		assertEquals(tokens.get(1).text,"simple");
		assertEquals(tokens.get(2).text,"</b>");
		assertEquals(tokens.get(3).text," test string");
		System.out.println(" OK");

		System.out.print("Test 3... ");
		tokens = Tokenizer.tokenize("\n<a href=\"test\"></a>");
		assertEquals(tokens.size(),3);
		assertEquals(tokens.get(0).text,"\n");
		assertEquals(tokens.get(1).text,"<a href=\"test\">");
		assertEquals(tokens.get(2).text,"</a>");
		System.out.println(" OK");

		System.out.print("Test 4... ");
		tokens = Tokenizer.tokenize("this is <img alt=\"a test 1>2\"> image.");
		assertEquals(tokens.size(),3);
		assertEquals(tokens.get(0).text,"this is ");
		assertEquals(tokens.get(1).text,"<img alt=\"a test 1>2\">");
		assertEquals(tokens.get(2).text," image.");
		System.out.println(" OK");

		System.out.print("Test 5... ");
		tokens = Tokenizer.tokenize("<p>simple test</p>\nstring.<!-- test - -> -->");
		assertEquals(tokens.size(),5);
		assertEquals(tokens.get(0).text,"<p>");
		assertEquals(tokens.get(1).text,"simple test");
		assertEquals(tokens.get(2).text,"</p>");
		assertEquals(tokens.get(3).text,"\nstring.");
		assertEquals(tokens.get(4).text,"<!-- test - -> -->");
		System.out.println(" OK");

		System.out.print("Test 6... ");
		tokens = Tokenizer.tokenize("correct processing of <img alt=\"cat's\"> apostrophe? <img alt='cat\"s'>");
		assertEquals(tokens.size(),4);
		assertEquals(tokens.get(0).text,"correct processing of ");
		assertEquals(tokens.get(1).text,"<img alt=\"cat's\">");
		assertEquals(tokens.get(2).text," apostrophe? ");
		assertEquals(tokens.get(3).text,"<img alt='cat\"s'>");
		System.out.println(" OK");

		System.out.print("Test 6... ");
		tokens = Tokenizer.tokenize("correct processing of <img alt=\"cat\"s\"> apostrophe? <img alt='cat\"s'>");
		assertEquals(tokens.size(),2);
		assertEquals(tokens.get(0).text,"correct processing of ");
		assertEquals(tokens.get(1).text,"<img alt=\"cat\"s\"> apostrophe? <img alt='cat\"s'>");
		System.out.println(" OK");

		System.out.print("Test 7... ");
		tokens = Tokenizer.tokenize("correct processing of <img alt=\"cat\"s\"> apostrophe? <img alt='cats'>");
		assertEquals(tokens.size(),2);
		assertEquals(tokens.get(0).text,"correct processing of ");
		assertEquals(tokens.get(1).text,"<img alt=\"cat\"s\"> apostrophe? <img alt='cats'>");
		System.out.println(" OK");

		System.out.print("Test 8... ");		
		tokens = Tokenizer.tokenize("<b>test</b> again.");
		tokens = TokenFilter.filterTokens(tokens, new String[]{"b"});
		assertEquals(tokens.size(),4);
		System.out.println(" OK");

		System.out.print("Test 9... ");		
		tokens = Tokenizer.tokenize("<i>test</i> again.");
		tokens = TokenFilter.filterTokens(tokens, new String[]{"b"});
		assertEquals(tokens.size(),2);
		System.out.println(" OK");

		System.out.print("Test 10... ");
		tokens = Tokenizer.tokenize("This is <b class=\"b\">a</b><br/> <i>test</i> again.");
		tokens = TokenFilter.filterTokens(tokens, new String[]{"b","i"});
		assertEquals(tokens.size(),9);
		assertEquals(Tokenizer.untokenize(tokens),"This is <b class=\"b\">a</b> <i>test</i> again.");
		System.out.println(" OK");

		System.out.print("Test 11... ");		
		tokens = Tokenizer.tokenize("This is <a class=\"b\">a</a><br/> <i>test</i> again.");
		tokens = TokenFilter.filterTokens(tokens, new String[]{"br","b","i"});
		assertEquals(tokens.size(),8);
		assertEquals(tokens.get(0).text,"This is ");
		assertEquals(tokens.get(1).text,"a");
		assertEquals(tokens.get(2).text,"<br/>");
		assertEquals(tokens.get(3).text," ");
		assertEquals(tokens.get(4).text,"<i>");
		assertEquals(tokens.get(5).text,"test");
		assertEquals(tokens.get(6).text,"</i>");
		assertEquals(tokens.get(7).text," again.");
		assertEquals(Tokenizer.untokenize(tokens),"This is a<br/> <i>test</i> again.");
		System.out.println(" OK");

		System.out.print("Test 12... ");		
		tokens = Tokenizer.tokenize("This is <? xml junk><!-- test <i> --><b>a</b> <i>test</i> again.");
		tokens = TokenFilter.filterTokens(tokens, new String[]{"b","i"});
		assertEquals(tokens.size(),9);
		assertEquals(tokens.get(0).text,"This is ");
		assertEquals(tokens.get(1).text,"<b>");
		assertEquals(tokens.get(2).text,"a");
		assertEquals(tokens.get(3).text,"</b>");
		assertEquals(tokens.get(4).text," ");
		assertEquals(tokens.get(5).text,"<i>");
		assertEquals(tokens.get(6).text,"test");
		assertEquals(tokens.get(7).text,"</i>");
		assertEquals(tokens.get(8).text," again.");
		assertEquals(Tokenizer.untokenize(tokens),"This is <b>a</b> <i>test</i> again.");
		System.out.println(" OK");

		System.out.print("Test 13... ");		
		String html = TokenFilter.filterTokens("Today <b>we</b> went to the <i>zoo</i>.", new String[]{"b","i","br"});
		assertEquals(html,"Today <b>we</b> went to the <i>zoo</i>.");
		System.out.println(" OK");

		System.out.print("Test 14... ");		
		html = TokenFilter.filterTokens("Today <b>we</b> went to the <i>zoo</i>.", new String[]{"i"});
		assertEquals(html,"Today we went to the <i>zoo</i>.");
		System.out.println(" OK");

	}

}
