/*
Redistribution and use in source and binary forms, with or without
modification, is permitted.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
THE POSSIBILITY OF SUCH DAMAGE.
 */
import au.edu.unimelb.htmltokenizer.HtmlTokenizer;
import au.edu.unimelb.htmltokenizer.TextTokenizer;
import au.edu.unimelb.htmltokenizer.Token;
import au.edu.unimelb.htmltokenizer.TokenFilter;
import au.edu.unimelb.htmltokenizer.Tokenizer;
import java.util.List;

/**
 * Test for correct tokenization of various strings.
 */
public class TestTextParser {

	public static void assertEquals(int a, int b) {
		if(a != b) throw new RuntimeException(a+"!="+b);
	}

	public static void assertEquals(String a, String b) {
		if(!a.equals(b)) throw new RuntimeException("\""+a+"\"!=\""+b+"\"");
	}

	public static void main(String[] arg) {

		List<Token> tokens = null;

		System.out.print("Test 1... ");
		tokens = TextTokenizer.tokenize("simple test string");
		assertEquals(tokens.size(),5);
		assertEquals(tokens.get(0).text,"simple");
		assertEquals(tokens.get(1).text," ");
		assertEquals(tokens.get(2).text,"test");
		assertEquals(tokens.get(3).text," ");
		assertEquals(tokens.get(4).text,"string");
		System.out.println(" OK");

		System.out.print("Test 2... ");
		tokens = TextTokenizer.tokenize("simple test \n string ");
		assertEquals(tokens.size(),6);
		assertEquals(tokens.get(0).text,"simple");
		assertEquals(tokens.get(1).text," ");
		assertEquals(tokens.get(2).text,"test");
		assertEquals(tokens.get(3).text," \n ");
		assertEquals(tokens.get(4).text,"string");
		assertEquals(tokens.get(1).text," ");
		System.out.println(" OK");

		System.out.print("Test 3... ");
		tokens = TextTokenizer.tokenize("simple. \"test\" \n string ");
		assertEquals(tokens.size(),9);
		assertEquals(tokens.get(0).text,"simple");
		assertEquals(tokens.get(1).text,".");
		assertEquals(tokens.get(2).text," ");
		assertEquals(tokens.get(3).text,"\"");
		assertEquals(tokens.get(4).text,"test");
		assertEquals(tokens.get(5).text,"\"");
		assertEquals(tokens.get(6).text," \n ");
		assertEquals(tokens.get(7).text,"string");
		assertEquals(tokens.get(8).text," ");
		System.out.println(" OK");

		System.out.print("Test 4... ");
		tokens = TextTokenizer.tokenize(" simple. \"");
		assertEquals(tokens.size(),5);
		assertEquals(tokens.get(0).text," ");
		assertEquals(tokens.get(1).text,"simple");
		assertEquals(tokens.get(2).text,".");
		assertEquals(tokens.get(3).text," ");
		assertEquals(tokens.get(4).text,"\"");
		System.out.println(" OK");

	}

}
